==> mingw-w64-libconfini-1.13.0-1.src.tar.gz: libconfini-1.13.0/docs/html/search/all_2.js <==
var searchData=
[
  ['compiling_20without_20the_20c_20standard_20library_4',['Compiling without the C Standard Library',['../baremetal.html',1,'']]],
  ['case_5fsensitive_5',['case_sensitive',['../structIniFormat.html#a50f562eda0d26ed7e0d3c57afeb46d2d',1,'IniFormat']]],
  ['changelog_6',['ChangeLog',['../changelog.html',1,'']]],
  ['changelog_2emd_7',['ChangeLog.md',['../ChangeLog_8md.html',1,'']]],
  ['collapse_5fempty_5fquotes_8',['collapse_empty_quotes',['../confini_8c.html#a6dfd90309965c426ac9b072d79a08601',1,'confini.c']]],
  ['collapse_5feverything_9',['collapse_everything',['../confini_8c.html#a0ab1c9f49e30ee6f637c213a27738d21',1,'confini.c']]],
  ['collapse_5fspaces_10',['collapse_spaces',['../confini_8c.html#a6ace46ed55f0c50e6314cb4610c536ab',1,'confini.c']]],
  ['confini_2ec_11',['confini.c',['../confini_8c.html',1,'']]],
  ['confini_2eh_12',['confini.h',['../confini_8h.html',1,'']]],
  ['confini_5febadf_13',['CONFINI_EBADF',['../confini_8h.html#a4b42cb63e48154fb799599eccd25ce29abea4607cf9d97028cd782ceb2885b2d9',1,'confini.h']]],
  ['confini_5fefbig_14',['CONFINI_EFBIG',['../confini_8h.html#a4b42cb63e48154fb799599eccd25ce29a20bea3ecf7dd504f5446a5983ed3fc0d',1,'confini.h']]],
  ['confini_5feio_15',['CONFINI_EIO',['../confini_8h.html#a4b42cb63e48154fb799599eccd25ce29a8b9b6ea5c455bfad3976fd394c36a91d',1,'confini.h']]],
  ['confini_5fenoent_16',['CONFINI_ENOENT',['../confini_8h.html#a4b42cb63e48154fb799599eccd25ce29aca147c275760856386fdb9e778525676',1,'confini.h']]],
  ['confini_5fenomem_17',['CONFINI_ENOMEM',['../confini_8h.html#a4b42cb63e48154fb799599eccd25ce29a0e8e1cee80bc4b7839838764f5d661f5',1,'confini.h']]],
  ['confini_5feoor_18',['CONFINI_EOOR',['../confini_8h.html#a4b42cb63e48154fb799599eccd25ce29a82e26058d2b7bb2203fe321d0320d98a',1,'confini.h']]],
  ['confini_5ferror_19',['CONFINI_ERROR',['../confini_8h.html#a0b9dcb5c0711475ea78b065b0322bde1',1,'confini.h']]],
  ['confini_5ffeintr_20',['CONFINI_FEINTR',['../confini_8h.html#a4b42cb63e48154fb799599eccd25ce29a133a335ff201d93015a27bd581e6b399',1,'confini.h']]],
  ['confini_5fiintr_21',['CONFINI_IINTR',['../confini_8h.html#a4b42cb63e48154fb799599eccd25ce29a1435b36fb0e428e18c5f6a32408eb3ea',1,'confini.h']]],
  ['confini_5fio_5fflavor_22',['CONFINI_IO_FLAVOR',['../confini_8c.html#aff2761409196287c45bb8876c8613aae',1,'confini.c']]],
  ['confini_5fsuccess_23',['CONFINI_SUCCESS',['../confini_8h.html#a4b42cb63e48154fb799599eccd25ce29ab6180fd6db09408e11eb1c27fb7028e7',1,'confini.h']]],
  ['confiniinterruptno_24',['ConfiniInterruptNo',['../confini_8h.html#a4b42cb63e48154fb799599eccd25ce29',1,'confini.h']]]
];

==> mingw-w64-libconfini-1.14.1-1.src.tar.gz: libconfini-1.14.1/docs/html/search/all_2.js <==
var searchData=
[
  ['compiling_20without_20the_20c_20standard_20library_4',['Compiling without the C Standard Library',['../baremetal.html',1,'']]],
  ['case_5fsensitive_5',['case_sensitive',['../structIniFormat.html#a50f562eda0d26ed7e0d3c57afeb46d2d',1,'IniFormat']]],
  ['changelog_6',['ChangeLog',['../changelog.html',1,'']]],
  ['changelog_2emd_7',['ChangeLog.md',['../ChangeLog_8md.html',1,'']]],
  ['collapse_5fempty_5fquotes_8',['collapse_empty_quotes',['../confini_8c.html#a6dfd90309965c426ac9b072d79a08601',1,'confini.c']]],
  ['collapse_5feverything_9',['collapse_everything',['../confini_8c.html#a0ab1c9f49e30ee6f637c213a27738d21',1,'confini.c']]],
  ['collapse_5fspaces_10',['collapse_spaces',['../confini_8c.html#a6ace46ed55f0c50e6314cb4610c536ab',1,'confini.c']]],
  ['confini_2ec_11',['confini.c',['../confini_8c.html',1,'']]],
  ['confini_2eh_12',['confini.h',['../confini_8h.html',1,'']]],
  ['confini_5febadf_13',['CONFINI_EBADF',['../confini_8h.html#a4b42cb63e48154fb799599eccd25ce29abea4607cf9d97028cd782ceb2885b2d9',1,'confini.h']]],
  ['confini_5fefbig_14',['CONFINI_EFBIG',['../confini_8h.html#a4b42cb63e48154fb799599eccd25ce29a20bea3ecf7dd504f5446a5983ed3fc0d',1,'confini.h']]],
  ['confini_5feio_15',['CONFINI_EIO',['../confini_8h.html#a4b42cb63e48154fb799599eccd25ce29a8b9b6ea5c455bfad3976fd394c36a91d',1,'confini.h']]],
  ['confini_5fenoent_16',['CONFINI_ENOENT',['../confini_8h.html#a4b42cb63e48154fb799599eccd25ce29aca147c275760856386fdb9e778525676',1,'confini.h']]],
  ['confini_5fenomem_17',['CONFINI_ENOMEM',['../confini_8h.html#a4b42cb63e48154fb799599eccd25ce29a0e8e1cee80bc4b7839838764f5d661f5',1,'confini.h']]],
  ['confini_5feoor_18',['CONFINI_EOOR',['../confini_8h.html#a4b42cb63e48154fb799599eccd25ce29a82e26058d2b7bb2203fe321d0320d98a',1,'confini.h']]],
  ['confini_5feroaddr_19',['CONFINI_EROADDR',['../confini_8h.html#a4b42cb63e48154fb799599eccd25ce29a701eeae64743243474d43bc85d7b3265',1,'confini.h']]],
  ['confini_5ferror_20',['CONFINI_ERROR',['../confini_8h.html#a0b9dcb5c0711475ea78b065b0322bde1',1,'confini.h']]],
  ['confini_5ffeintr_21',['CONFINI_FEINTR',['../confini_8h.html#a4b42cb63e48154fb799599eccd25ce29a133a335ff201d93015a27bd581e6b399',1,'confini.h']]],
  ['confini_5fiintr_22',['CONFINI_IINTR',['../confini_8h.html#a4b42cb63e48154fb799599eccd25ce29a1435b36fb0e428e18c5f6a32408eb3ea',1,'confini.h']]],
  ['confini_5fio_5fflavor_23',['CONFINI_IO_FLAVOR',['../confini_8c.html#aff2761409196287c45bb8876c8613aae',1,'confini.c']]],
  ['confini_5fsuccess_24',['CONFINI_SUCCESS',['../confini_8h.html#a4b42cb63e48154fb799599eccd25ce29ab6180fd6db09408e11eb1c27fb7028e7',1,'confini.h']]],
  ['confiniinterruptno_25',['ConfiniInterruptNo',['../confini_8h.html#a4b42cb63e48154fb799599eccd25ce29',1,'confini.h']]]
];
